@@ -968,7 +968,7 @@ class FineTransformerWrapper(nn.Module):
         self_attn_mask = coarse_token_ids != self.pad_id
 
         fine_token_seq_len = fine_token_ids.shape[-1]
-        self_attn_mask = F.pad(self_attn_mask, (1, fine_token_seq_len + 1))
+        self_attn_mask = F.pad(self_attn_mask, (1, fine_token_seq_len + 1), value = True)
 
         coarse_logits, fine_logits = self.transformer(
             coarse_token_ids = coarse_token_ids,
